You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@allura.apache.org by br...@apache.org on 2020/10/30 21:47:37 UTC

[allura] 07/10: [#8260] custom build of EasyMDE so we can access CodeMirror lib https://github.com/Ionaru/easy-markdown-editor/pull/263

This is an automated email from the ASF dual-hosted git repository.

brondsem pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/allura.git

commit 184f7f87c8cf62bfa7421b343d90ccaf28f66f38
Author: Dave Brondsema <db...@slashdotmedia.com>
AuthorDate: Fri Oct 30 20:43:21 2020 +0000

    [#8260] custom build of EasyMDE so we can access CodeMirror lib https://github.com/Ionaru/easy-markdown-editor/pull/263
---
 Allura/allura/lib/widgets/resources/js/easymde.min.js | 2 +-
 Allura/allura/lib/widgets/resources/js/sf_markitup.js | 3 ++-
 2 files changed, 3 insertions(+), 2 deletions(-)

diff --git a/Allura/allura/lib/widgets/resources/js/easymde.min.js b/Allura/allura/lib/widgets/resources/js/easymde.min.js
index d551d6f..4771250 100644
--- a/Allura/allura/lib/widgets/resources/js/easymde.min.js
+++ b/Allura/allura/lib/widgets/resources/js/easymde.min.js
@@ -4,4 +4,4 @@
  * @link https://github.com/ionaru/easy-markdown-editor
  * @license MIT
  */
-!function(e){if("object"==typeof exports&&"undefined"!=typeof module)module.exports=e();else if("function"==typeof define&&define.amd)define([],e);else{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:this).EasyMDE=e()}}((function(){return function e(t,n,r){function i(a,l){if(!n[a]){if(!t[a]){var s="function"==typeof require&&require;if(!l&&s)return s(a,!0);if(o)return o(a,!0);var c=new Error("Cannot find module '"+a+"'");throw c.code="MO [...]
\ No newline at end of file
+!function(e){if("object"==typeof exports&&"undefined"!=typeof module)module.exports=e();else if("function"==typeof define&&define.amd)define([],e);else{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:this).EasyMDE=e()}}((function(){return function e(t,n,r){function i(a,l){if(!n[a]){if(!t[a]){var s="function"==typeof require&&require;if(!l&&s)return s(a,!0);if(o)return o(a,!0);var c=new Error("Cannot find module '"+a+"'");throw c.code="MO [...]
\ No newline at end of file
diff --git a/Allura/allura/lib/widgets/resources/js/sf_markitup.js b/Allura/allura/lib/widgets/resources/js/sf_markitup.js
index 831e076..b225674 100644
--- a/Allura/allura/lib/widgets/resources/js/sf_markitup.js
+++ b/Allura/allura/lib/widgets/resources/js/sf_markitup.js
@@ -17,7 +17,8 @@
        under the License.
 */
 
-/*global SimpleMDE, _replaceSelection, Memorable */
+/*global EasyMDE, _replaceSelection, Memorable */
+window.CodeMirror = EasyMDE.CodeMirror; // https://github.com/Ionaru/easy-markdown-editor/pull/263
 $(window).load(function() {
     if(!window.markdown_init){
         window.markdown_init = true;